==> nextcloud-jitsi-v0.18.0.tar.gz: jitsi/l10n/fr.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "conférences",
    "Jitsi Integration" : "Intégration de Jitsi",
    "Conferences" : "Conférences",
    "Jitsi Integration (unofficial)" : "Intégration de Jitsi (non officielle)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Cette application intègre les conférences Jitsi dans Nextcloud.\n\nCaractéristiques :\n- 🎥 Conférences en ligne faciles dans Nextcloud en utilisant Jitsi.\n- 🔗 Liens de partage des salles de conférence\n- 🔎 Affichage des salles de conférence dans la recherche unifiée\n- ✅ Test du système avant de rejoindre une salle\n\nVeuillez lire la [documentation] (https://github.com/nextcloud/jitsi).",
    "Loading …" : "Chargement...",
    "Server URL (required)" : "URL du serveur (requise)",
    "Help link (optional)" : "Lien d'aide (optionnel)",
    "Display \"Join using the Jitsi app\"" : "Afficher \"Rejoindre en utilisant l'application Jitsi\"",
    "JWT Secret (optional)" : "Secret JWT (facultatif)",
    "JWT App ID" : "ID d'application JWT",
    "JWT Audience (optional)" : "Destinataire JWT (\"Audience\", facultatif)",
    "JWT Issuer (optional)" : "Émetteur JWT (\"Issuer\", facultatif)",
    "save" : "enregistrer",
    "saved" : "enregistré",
    "Saving …" : "Sauvegarde...",
    "Please provide a Jitsi instance URL" : "Veuillez fournir l'URL d'une instance Jitsi",
    "The server URL must start with https://" : "L'URL du serveur doit commencer par https://",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Il est fortement recommandé de mettre en place une instance Jitsi dédiée",
    "Please provide the App ID" : "Veuillez fournir l'ID de l'app",
    "Failed to save settings" : "Echec de la sauvegarde des paramètres",
    "Failed to load settings" : "Echec du chargement des paramètres",
    "Conference rooms" : "Salle de conférences",
    "Conference" : "Conférence",
    "Conference left" : "Conférence quittée",
    "Problems detected" : "Problèmes détectés",
    "Your browser is non-optimal:" : "Votre navigateur n'est pas optimal :",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "La qualité audio and vidéo pourrait être faible. Il est recommandé d'utiliser une version récente de <b>Firefox/Chrome/Chromium</b>.",
    "Browser not supported" : "Navigateur non compatible",
    "Show system check" : "Afficher les vérifications systèmes",
    "Your name:" : "Votre nom :",
    "Click here to join" : "Cliquez ici pour rejoindre",
    "Start muted" : "Démarrer micro éteint",
    "Start with camera off" : "Démarrer avec la caméra éteinte",
    "Join with desktop app" : "Joindre avec l'application de bureau",
    "Join with mobile app" : "Joindre avec l'application mobile",
    "App button not working?" : "Le bouton de l'application ne fonctionne pas ?",
    "Download the desktop app here ↗" : "Télécharger l'application de bureau ici ↗",
    "The mobile app is available via the app store of your choice." : "L'application mobile est disponible dans le magasin d'application de votre choix.",
    "After successful installation try the button again." : "Essayer à nouveau le bouton après une installation réussie.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Toujours pas fonctionnel ? Copier le lien ci-dessous et le coller dans le champ de saisie de l'écran de démarrage de l'application Jitsi.",
    "Link copied" : "Lien copié",
    "Cannot copy, please copy the link manually" : "Impossible de copier, merci de copier le lien manuellement",
    "Copy to clipboard" : "Copier dans le presse-papiers",
    "Browser" : "Navigateur",
    "non-optimal" : "non-optimal",
    "not supported" : "non pris en charge",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "La qualité audio et vidéo pourrait être faible.<br>Il est recommandé d'utiliser<b>une version récente de</b>Firefox/Chrome/Chromium.",
    "Help" : "Aide",
    "Camera" : "Caméra",
    "Name of the new room" : "Nom de la nouvelle salle",
    "No conference rooms yet" : "Aucune salle de conférence pour l'instant",
    "Create the first room:" : "Créez tout d'abord une salle",
    "Microphone" : "Microphone",
    "Join" : "Rejoindre",
    "Delete room" : "Supprimer la salle",
    "Room not found" : "Salle non trouvée",
    "Please check the link/URL and ask your host" : "Veuillez vérifier le lien/URL et demander à votre hébergeur",
    "Audio output" : "Sortie audio",
    "Play test sound" : "Jouer un son test",
    "System check" : "Vérification du système",
    "Got issues?" : "Des problèmes ?",
    "Known problems / what you can try" : "Problèmes connus / Ce que vous pouvez essayer",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Acceptez les autorisations d'accès au microphone/à la webcam en haut de l'écran.",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Vérifiez les autorisations d'accès au microphone/à la webcam en cliquant sur l'icône située à côté de la barre d'adresse. Rechargez ensuite la page.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Si vous avez DroidCam : Connectez-vous à la caméra mobile, puis rechargez la page.",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Essayez de rejoindre en utilisant l'application Jitsi (suivez les instructions au bas de la page).",
    "No camera/microphone access" : "Aucun accès à la caméra / au microphone",
    "Review your browser camera and microphone access settings" : "Vérifiez les paramètres d'accès à la caméra et au microphone de votre navigateur",
    "Click here for {browser} instructions" : "Cliquer ici pour les instructions pour {browser}",
    "Does not work?" : "Ne fonctionne pas ?",
    "Click here for troubleshooting help" : "Cliquez ici pour l'aide au dépannage",
    "Conferences app not yet configured" : "Application de conférence pas encore configurée",
    "Please contact your administrator to set up the conferences app." : "Veuillez contacter votre administrateur pour configurer votre application de conférences",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Votre navigateur (%1$s) est obsolète et<br>n'est plus pris en charge",
    "It is recommended to use the latest version of one of the following browsers:" : "Il est recommandé d'utiliser la dernière version de l'un des navigateurs suivants :"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-jitsi-v0.19.0.tar.gz: jitsi/l10n/fr.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "conférences",
    "Jitsi Integration" : "Intégration de Jitsi",
    "Conferences" : "Conférences",
    "Jitsi Integration (unofficial)" : "Intégration de Jitsi (non officielle)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Cette application intègre les conférences Jitsi dans Nextcloud.\n\nCaractéristiques :\n- 🎥 Conférences en ligne faciles dans Nextcloud en utilisant Jitsi.\n- 🔗 Liens de partage des salles de conférence\n- 🔎 Affichage des salles de conférence dans la recherche unifiée\n- ✅ Test du système avant de rejoindre une salle\n\nVeuillez lire la [documentation] (https://github.com/nextcloud/jitsi).",
    "Loading …" : "Chargement...",
    "Server URL (required)" : "URL du serveur (requise)",
    "Help link (optional)" : "Lien d'aide (optionnel)",
    "Display \"Join using the Jitsi app\"" : "Afficher \"Rejoindre en utilisant l'application Jitsi\"",
    "JWT Secret (optional)" : "Secret JWT (facultatif)",
    "JWT App ID" : "ID d'application JWT",
    "JWT Audience (optional)" : "Destinataire JWT (\"Audience\", facultatif)",
    "JWT Issuer (optional)" : "Émetteur JWT (\"Issuer\", facultatif)",
    "save" : "enregistrer",
    "saved" : "enregistré",
    "Saving …" : "Sauvegarde...",
    "Please provide a Jitsi instance URL" : "Veuillez fournir l'URL d'une instance Jitsi",
    "The server URL must start with https://" : "L'URL du serveur doit commencer par https://",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Il est fortement recommandé de mettre en place une instance Jitsi dédiée",
    "Please provide the App ID" : "Veuillez fournir l'ID de l'app",
    "Failed to save settings" : "Échec de la sauvegarde des paramètres",
    "Failed to load settings" : "Échec du chargement des paramètres",
    "Conference rooms" : "Salle de conférences",
    "Conference" : "Conférence",
    "Conference left" : "Conférence quittée",
    "Problems detected" : "Problèmes détectés",
    "Your browser is non-optimal:" : "Votre navigateur n'est pas optimal :",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "La qualité audio and vidéo pourrait être faible. Il est recommandé d'utiliser une version récente de <b>Firefox/Chrome/Chromium</b>.",
    "Browser not supported" : "Navigateur non compatible",
    "Show system check" : "Afficher les vérifications systèmes",
    "Your name:" : "Votre nom :",
    "Click here to join" : "Cliquez ici pour rejoindre",
    "Start muted" : "Démarrer micro éteint",
    "Start with camera off" : "Démarrer avec la caméra éteinte",
    "Join with desktop app" : "Joindre avec l'application de bureau",
    "Join with mobile app" : "Joindre avec l'application mobile",
    "App button not working?" : "Le bouton de l'application ne fonctionne pas ?",
    "Download the desktop app here ↗" : "Télécharger l'application de bureau ici ↗",
    "The mobile app is available via the app store of your choice." : "L'application mobile est disponible dans le magasin d'application de votre choix.",
    "After successful installation try the button again." : "Essayer à nouveau le bouton après une installation réussie.",
    "Still not working? Copy the link below and paste it into the input field on the Jitsi App start screen." : "Toujours pas fonctionnel ? Copier le lien ci-dessous et le coller dans le champ de saisie de l'écran de démarrage de l'application Jitsi.",
    "Link copied" : "Lien copié",
    "Cannot copy, please copy the link manually" : "Impossible de copier, merci de copier le lien manuellement",
    "Copy to clipboard" : "Copier dans le presse-papiers",
    "Browser" : "Navigateur",
    "non-optimal" : "non-optimal",
    "not supported" : "non pris en charge",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "La qualité audio et vidéo pourrait être faible.<br>Il est recommandé d'utiliser<b>une version récente de</b>Firefox/Chrome/Chromium.",
    "Help" : "Aide",
    "Camera" : "Caméra",
    "Name of the new room" : "Nom de la nouvelle salle",
    "No conference rooms yet" : "Aucune salle de conférence pour l'instant",
    "Create the first room:" : "Créez tout d'abord une salle",
    "Microphone" : "Microphone",
    "Join" : "Rejoindre",
    "Delete room" : "Supprimer la salle",
    "Room not found" : "Salle non trouvée",
    "Please check the link/URL and ask your host" : "Veuillez vérifier le lien/URL et demander à votre hébergeur",
    "Audio output" : "Sortie audio",
    "Play test sound" : "Jouer un son test",
    "System check" : "Vérification du système",
    "Got issues?" : "Des problèmes ?",
    "Known problems / what you can try" : "Problèmes connus / Ce que vous pouvez essayer",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Acceptez les autorisations d'accès au microphone/à la webcam en haut de l'écran.",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Vérifiez les autorisations d'accès au microphone/à la webcam en cliquant sur l'icône située à côté de la barre d'adresse. Rechargez ensuite la page.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Si vous avez DroidCam : Connectez-vous à la caméra mobile, puis rechargez la page.",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Essayez de rejoindre en utilisant l'application Jitsi (suivez les instructions au bas de la page).",
    "No camera/microphone access" : "Aucun accès à la caméra / au microphone",
    "Review your browser camera and microphone access settings" : "Vérifiez les paramètres d'accès à la caméra et au microphone de votre navigateur",
    "Click here for {browser} instructions" : "Cliquer ici pour les instructions pour {browser}",
    "Does not work?" : "Ne fonctionne pas ?",
    "Click here for troubleshooting help" : "Cliquez ici pour l'aide au dépannage",
    "Conferences app not yet configured" : "Application de conférence pas encore configurée",
    "Please contact your administrator to set up the conferences app." : "Veuillez contacter votre administrateur pour configurer votre application de conférences",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Votre navigateur (%1$s) est obsolète et<br>n'est plus pris en charge",
    "It is recommended to use the latest version of one of the following browsers:" : "Il est recommandé d'utiliser la dernière version de l'un des navigateurs suivants :"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
